@@ -90,7 +90,7 @@ void CiscoCertificateEnrollment::reject()
 	if ( EnrollmentProcess != 0 && EnrollmentProcess->isRunning() )
 	{
 		EnrollmentProcess->tryTerminate();
-		TQTimer::singleShot ( 2000, EnrollmentProcess, TQT_SLOT ( kill() ) );
+		TQTimer::singleShot ( 2000, EnrollmentProcess, TQ_SLOT ( kill() ) );
 
 		if ( GlobalConfig->KvpncDebugLevel > 2 )
 			GlobalConfig->appendLogEntry ( i18n ( "process %1 killed" ).arg ( "cisco_cert_mgr" ), GlobalConfig->debug );
@@ -106,8 +106,8 @@ void CiscoCertificateEnrollment::setupPages()
 	selectionpage->sizeHint();
 	addPage ( selectionpage, "<b>" + i18n ( "Select enrollment type..." ) + "</b>" );
 
-	connect ( selectionpage->FileEnrollementRadioButton, TQT_SIGNAL ( toggled ( bool ) ), this, TQT_SLOT ( enrollmentToggled ( bool ) ) );
-	connect ( selectionpage->OnlineEnrollementRadioButton, TQT_SIGNAL ( toggled ( bool ) ), this, TQT_SLOT ( enrollmentToggled ( bool ) ) );
+	connect ( selectionpage->FileEnrollementRadioButton, TQ_SIGNAL ( toggled ( bool ) ), this, TQ_SLOT ( enrollmentToggled ( bool ) ) );
+	connect ( selectionpage->OnlineEnrollementRadioButton, TQ_SIGNAL ( toggled ( bool ) ), this, TQ_SLOT ( enrollmentToggled ( bool ) ) );
 
 	GlobalConfig->slotStatusMsg(i18n("Collecting cisco CA certs from Cisco certificate store..."), ID_STATUS_MSG);
 	if (GlobalConfig->KvpncDebugLevel > 2)
@@ -178,7 +178,7 @@ void CiscoCertificateEnrollment::next ()
 
 				else if ( GlobalConfig->KvpncDebugLevel > 4 )
 					GlobalConfig->appendLogEntry ( i18n ( "Password (cleartext): %1" ).arg ( selectionpage->NewPasswordPasswordEdit->password() ), KVpncConfig::debug );
-				ChallengePassword =TQString(selectionpage->NewPasswordPasswordEdit->password());
+				ChallengePassword = selectionpage->NewPasswordPasswordEdit->password();
 			}
 
 			if ( GlobalConfig->KvpncDebugLevel > 2 )
@@ -225,7 +225,7 @@ void CiscoCertificateEnrollment::next ()
 
 				else if ( GlobalConfig->KvpncDebugLevel > 4 )
 					GlobalConfig->appendLogEntry ( i18n ( "Challenge password (cleartext): %1" ).arg ( selectionpage->ChallengePasswordPasswordEdit->password() ), KVpncConfig::debug );
-				ChallengePassword =TQString(selectionpage->ChallengePasswordPasswordEdit->password());
+				ChallengePassword = selectionpage->ChallengePasswordPasswordEdit->password();
 			}
 
 		}
@@ -373,9 +373,9 @@ void CiscoCertificateEnrollment::next ()
 
 		}
 
-		connect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout() ) );
-		connect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr() ) );
-		connect ( EnrollmentProcess, TQT_SIGNAL ( processExited()) , this, TQT_SLOT(enrollmentProcessFinished()));
+		connect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout() ) );
+		connect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr() ) );
+		connect ( EnrollmentProcess, TQ_SIGNAL ( processExited()) , this, TQ_SLOT(enrollmentProcessFinished()));
 
 // 		if ( GlobalConfig->KvpncDebugLevel > 3 )
 		{
@@ -410,7 +410,7 @@ void CiscoCertificateEnrollment::next ()
 			ProgressDlg->show();
 			ProgressDlg->resize ( ProgressDlg->width() +100,ProgressDlg->height() );
 
-			connect ( &CheckEnrollmentTimer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( checkProgress() ) );
+			connect ( &CheckEnrollmentTimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( checkProgress() ) );
 			CheckEnrollmentTimer.start ( 500, FALSE );
 
 			// we stupid have to send the password :(
@@ -483,9 +483,9 @@ void CiscoCertificateEnrollment::showPage ( TQWidget* page )
 
 void CiscoCertificateEnrollment::enrollmentProcessFinished()
 {
-	disconnect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout() ) );
-	disconnect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr() ) );
-	disconnect ( EnrollmentProcess, TQT_SIGNAL ( processExited()) , this, TQT_SLOT(enrollmentProcessFinished()));
+	disconnect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout() ) );
+	disconnect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr() ) );
+	disconnect ( EnrollmentProcess, TQ_SIGNAL ( processExited()) , this, TQ_SLOT(enrollmentProcessFinished()));
 	if ( ProgressDlg!= 0 )
 		ProgressDlg->progressBar()->setValue ( 100 );
 	GlobalConfig->appPointer->restoreOverrideCursor();
@@ -633,12 +633,12 @@ void CiscoCertificateEnrollment::checkProgress()
 		CheckEnrollmentTimer.stop();
 
 		// kill process
-		disconnect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout() ) );
-		disconnect ( EnrollmentProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr() ) );
+		disconnect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout() ) );
+		disconnect ( EnrollmentProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr() ) );
 		if ( EnrollmentProcess->isRunning() )
 		{
 			EnrollmentProcess->tryTerminate();
-			TQTimer::singleShot ( 2000, EnrollmentProcess, TQT_SLOT ( kill() ) );
+			TQTimer::singleShot ( 2000, EnrollmentProcess, TQ_SLOT ( kill() ) );
 
 			if ( GlobalConfig->KvpncDebugLevel > 2 )
 				GlobalConfig->appendLogEntry ( i18n ( "process %1 killed" ).arg ( "cisco_cert_mgr" ), GlobalConfig->debug );
@@ -662,9 +662,9 @@ void CiscoCertificateEnrollment::checkProgress()
 				DeleteProcess->addArgument ( "delete" );
 				DeleteProcess->addArgument ( "-ct" );
 				DeleteProcess->addArgument ( 0 );
-				connect ( DeleteProcess, TQT_SIGNAL ( processExited()) , this, TQT_SLOT(cancelProcessFinished()));
-				connect ( DeleteProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout_cancel() ) );
-				connect ( DeleteProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr_cancel() ) );
+				connect ( DeleteProcess, TQ_SIGNAL ( processExited()) , this, TQ_SLOT(cancelProcessFinished()));
+				connect ( DeleteProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout_cancel() ) );
+				connect ( DeleteProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr_cancel() ) );
 
 				if ( !DeleteProcess->start ( env ) )
 				{
@@ -685,9 +685,9 @@ void CiscoCertificateEnrollment::checkProgress()
 						sleep(1);
 					}
 				}
-				disconnect ( DeleteProcess, TQT_SIGNAL ( processExited()) , this, TQT_SLOT(cancelProcessFinished()));
-				disconnect ( DeleteProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout_cancel() ) );
-				disconnect ( DeleteProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr_cancel() ) );
+				disconnect ( DeleteProcess, TQ_SIGNAL ( processExited()) , this, TQ_SLOT(cancelProcessFinished()));
+				disconnect ( DeleteProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout_cancel() ) );
+				disconnect ( DeleteProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr_cancel() ) );
 				delete DeleteProcess;
 				DeleteProcess=0L;
 
