@@ -70,10 +70,10 @@ ImportCertificateDialog::ImportCertificateDialog ( TQWidget *parent, const char*
 	env = new TQStringList();
 	*env << "LC_ALL=C" << "LANG=C" << "PATH=/bin:/usr/bin:/usr/sbin:/sbin";
 
-	connect ( main->ImporttypeComboBox, TQT_SIGNAL ( activated ( int ) ), this, TQT_SLOT ( typeToggeled ( int ) ) );
+	connect ( main->ImporttypeComboBox, TQ_SIGNAL ( activated ( int ) ), this, TQ_SLOT ( typeToggeled ( int ) ) );
 	typeToggeled ( main->ImporttypeComboBox->currentItem() );
 
-	connect (main->UsePrivateKeyPasswordCheckBox, TQT_SIGNAL( toggled(bool)), this, TQT_SLOT(usePrivateKeyPassToggled(bool)));
+	connect (main->UsePrivateKeyPasswordCheckBox, TQ_SIGNAL( toggled(bool)), this, TQ_SLOT(usePrivateKeyPassToggled(bool)));
 	usePrivateKeyPassToggled(main->UsePrivateKeyPasswordCheckBox->isChecked());
 
 	// TMP
@@ -259,7 +259,7 @@ void ImportCertificateDialog::accept()
 		}
 		if ( importOk )
 		{
-			if ( TQString ( main->PrivateKeyPasswordEdit->password() ) != TQString ( main->PrivateKeyAgainPasswordEdit->password() ) )
+			if ( main->PrivateKeyPasswordEdit->password() != main->PrivateKeyAgainPasswordEdit->password() )
 			{
 				importOk = false;
 				KMessageBox::sorry ( 0, i18n ( "Private key passwords does not match!" ), i18n ( "Passwords Do Not Match" ) );
@@ -268,7 +268,7 @@ void ImportCertificateDialog::accept()
 			}
 			else
 			{
-				privatekeypassword= TQString ( main->PrivateKeyAgainPasswordEdit->password() );
+				privatekeypassword = main->PrivateKeyAgainPasswordEdit->password();
 			}
 		}
 	}
@@ -291,7 +291,7 @@ void ImportCertificateDialog::accept()
 		}
 		if ( importOk )
 		{
-			if ( main->UsePrivateKeyPasswordCheckBox->isChecked() && (TQString ( main->PrivateKeyPasswordEdit->password() ) != TQString ( main->PrivateKeyAgainPasswordEdit->password() ) ))
+			if ( main->UsePrivateKeyPasswordCheckBox->isChecked() && (main->PrivateKeyPasswordEdit->password() != main->PrivateKeyAgainPasswordEdit->password() ))
 			{
 				importOk = false;
 				KMessageBox::sorry ( 0, i18n ( "Certificate passwords does not match!" ), i18n ( "Passwords Do Not Match" ) );
@@ -301,7 +301,7 @@ void ImportCertificateDialog::accept()
 			else
 			{
 				if (main->UsePrivateKeyPasswordCheckBox->isChecked() )
-					privatekeypassword= TQString ( main->PrivateKeyAgainPasswordEdit->password() );
+					privatekeypassword = main->PrivateKeyAgainPasswordEdit->password();
 			}
 		}
 	}
@@ -451,23 +451,23 @@ void ImportCertificateDialog::accept()
 		}
 
 
-		connect ( ImportProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout_import() ) );
-		connect ( ImportProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr_import() ) );
+		connect ( ImportProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout_import() ) );
+		connect ( ImportProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr_import() ) );
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
 		        main->ImporttypeComboBox->currentItem() == pkcs12_racoon ||
 		        main->ImporttypeComboBox->currentItem() == pkcs12_openvpn
 		   )
 		{
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doCacert() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doCacert() ) );
 		}
 		if ( main->ImporttypeComboBox->currentItem() == ca_der )
 		{
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doCreateHash() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doCreateHash() ) );
 		}
 
 		if ( main->ImporttypeComboBox->currentItem() == cisco || main->ImporttypeComboBox->currentItem() == ciscoca)
 		{
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( ciscoCertMgrExited() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( ciscoCertMgrExited() ) );
 		}
 
 		if ( !ImportProcess->start ( env ) )
@@ -509,8 +509,8 @@ void ImportCertificateDialog::accept()
 				ImportProcess->writeToStdin ( main->ImportPasswordEdit->text() +"\n");
 				if (main->UsePrivateKeyPasswordCheckBox->isChecked() )
 				{
-					ImportProcess->writeToStdin ( TQString ( main->PrivateKeyPasswordEdit->password() ) + "\n" );
-					ImportProcess->writeToStdin ( TQString ( main->PrivateKeyPasswordEdit->password() ) + "\n" );
+					ImportProcess->writeToStdin ( main->PrivateKeyPasswordEdit->password() + "\n" );
+					ImportProcess->writeToStdin ( main->PrivateKeyPasswordEdit->password() + "\n" );
 				}
 			}
 		}
@@ -640,7 +640,7 @@ void ImportCertificateDialog::reject()
 
 void ImportCertificateDialog::doCacert()
 {
-	disconnect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doCacert() ) );
+	disconnect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doCacert() ) );
 	if ( GlobalConfig->KvpncDebugLevel > 3 )
 		GlobalConfig->appendLogEntry ( i18n ( "Certificate import: %1" ).arg("doCacert()"),GlobalConfig->debug );
 
@@ -681,7 +681,7 @@ void ImportCertificateDialog::doCacert()
 
 		ImportProcess->addArgument ( "-nodes" );
 
-		connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doCreateHash() ) );
+		connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doCreateHash() ) );
 
 		if ( ! ImportProcess->start ( env ) )
 		{
@@ -719,7 +719,7 @@ void ImportCertificateDialog::doPrivateKey()
 
 	if ( GlobalConfig->KvpncDebugLevel > 3 )
 		GlobalConfig->appendLogEntry ( "[dbg]: doPrivateKey()",GlobalConfig->debug );
-	disconnect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doPrivateKey() ) );
+	disconnect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doPrivateKey() ) );
 
 	if ( ImportProcess->normalExit () )
 	{
@@ -748,9 +748,9 @@ void ImportCertificateDialog::doPrivateKey()
 			CertFullPath=certpath+"/" + certName + ".pem";
 
 		if ( main->UsePrivateKeyPasswordCheckBox->isChecked() )
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( exit() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( exit() ) );
 		else
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( removePrivateKey() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( removePrivateKey() ) );
 
 		//LogOutput->append( "priv key: we starting..." );
 		if ( !ImportProcess->start( ) )
@@ -823,7 +823,7 @@ void ImportCertificateDialog::doPrivateKey()
 void ImportCertificateDialog::doCreateHash()
 {
 
-	disconnect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doCreateHash() ) );
+	disconnect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doCreateHash() ) );
 
 	if ( GlobalConfig->KvpncDebugLevel > 3 )
 		GlobalConfig->appendLogEntry ( i18n ( "Certificate import: %1" ).arg("doCreateHash()"),GlobalConfig->debug );
@@ -850,7 +850,7 @@ void ImportCertificateDialog::doCreateHash()
 		else
 			ImportProcess->addArgument ( certpath + "/ca_" + certName + ".pem" );
 
-		connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doLink() ) );
+		connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doLink() ) );
 
 
 		//		LogOutput->append( "hash: we starting..." );
@@ -892,7 +892,7 @@ void ImportCertificateDialog::doCreateHash()
 
 void ImportCertificateDialog::doLink()
 {
-	disconnect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doLink() ) );
+	disconnect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doLink() ) );
 	if ( GlobalConfig->KvpncDebugLevel > 3 )
 		GlobalConfig->appendLogEntry ( i18n ( "Certificate import: %1" ).arg("doLink()"),GlobalConfig->debug );
 
@@ -919,9 +919,9 @@ void ImportCertificateDialog::doLink()
 
 		if ( main->ImporttypeComboBox->currentItem() == pkcs12_freeswan ||
 		        main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( doPrivateKey() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( doPrivateKey() ) );
 		else
-			connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( exit() ) );
+			connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( exit() ) );
 
 
 		if ( !ImportProcess->start( ) )
@@ -1054,7 +1054,7 @@ void ImportCertificateDialog::readFromStdout_import()
 			{
 				if ( GlobalConfig->KvpncDebugLevel > 0 )
 					GlobalConfig->appendLogEntry ( i18n ( "Certificate import: %1 was requested, send it..." ).arg ( i18n ( "certificate password" ) ),GlobalConfig->debug );
-				ImportProcess->writeToStdin ( TQString ( main->PrivateKeyPasswordEdit->password() ) + "\n" );
+				ImportProcess->writeToStdin ( main->PrivateKeyPasswordEdit->password() + "\n" );
 
 			}
 			if ( line.find ( "Success: certificate imported from path:", 0, FALSE ) > -1 )
@@ -1120,8 +1120,8 @@ void ImportCertificateDialog::readFromStderr_import()
 			error_found=true;
 // 			if ( ImportProcess != 0L && ImportProcess->isRunning() )
 // 			{
-// 				disconnect ( ImportProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readFromStdout_import() ) );
-// 				disconnect ( ImportProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readFromStderr_import() ) );
+// 				disconnect ( ImportProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readFromStdout_import() ) );
+// 				disconnect ( ImportProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readFromStderr_import() ) );
 // 				ImportProcess->kill();
 // 				ImportProcess = 0L;
 // 			}
@@ -1311,7 +1311,7 @@ void ImportCertificateDialog::usePrivateKeyPassToggled(bool)
 
 void ImportCertificateDialog::removePrivateKey()
 {
-	disconnect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( removePrivateKey() ) );
+	disconnect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( removePrivateKey() ) );
 	if ( GlobalConfig->KvpncDebugLevel > 3 )
 		GlobalConfig->appendLogEntry ( i18n ( "Certificate import: %1" ).arg("removePrivateKey()"),GlobalConfig->debug );
 
@@ -1334,7 +1334,7 @@ void ImportCertificateDialog::removePrivateKey()
 		else if ( main->ImporttypeComboBox->currentItem() == pkcs12_openvpn )
 			ImportProcess->addArgument ( certpath+"/" + certName + ".pem" ); // warning: static
 
-		connect ( ImportProcess, TQT_SIGNAL ( processExited () ), this, TQT_SLOT ( exit() ) );
+		connect ( ImportProcess, TQ_SIGNAL ( processExited () ), this, TQ_SLOT ( exit() ) );
 
 
 		if ( !ImportProcess->start( ) )
