@@ -33,10 +33,10 @@
 #include "kvpnc.h"
 static const char *description =
     I18N_NOOP ( "TDE frontend for various vpn clients\nCurrently supported protocols:\n* Cisco (vpnc (free), vpnclient (propritary))\n* IPSec (FreeS/WAN, Openswan, strongSwan, racoon)\n* PPTP\n* OpenVPN\n* L2TP (l2tpd, xl2tpd, openl2tp) over IPSec (racoon, FreeS/WAN, Openswan, strongSwan)\n* Vtun\n* SSH" );
-// TQDate().fromString(, Qt::LocalDate ).toString( "yyyyMMdd" )
+// TQDate().fromString(, TQt::LocalDate ).toString( "yyyyMMdd" )
 TQString date ( __DATE__ );
 TQString day= date.section ( ' ',0,0 );
-TQString month= TQString().setNum ( TQDate::fromString ( date.section ( ' ',0,0 ),Qt::ISODate ).month() );
+TQString month= TQString().setNum ( TQDate::fromString ( date.section ( ' ',0,0 ),TQt::ISODate ).month() );
 TQString year= date.section ( ' ',2,2 );
 
 TQString currentdate ( "+SVN(" + date+" "+ TQTime().fromString ( TQString ( __TIME__ ) ).toString ( "hhmm" ) + ")" );
