@@ -201,7 +201,7 @@ void ProfileNetworkRouteOptions::contextMenuRequested ( TQListViewItem * item, c
 		ContextMenu->insertItem(i18n("&Delete..."));
 	}
 	ContextMenu->insertItem(i18n("&Add..."));
-	connect ( ContextMenu, TQT_SIGNAL ( activated ( int ) ), this, TQT_SLOT ( doContextMenuAction ( int ) ) );
+	connect ( ContextMenu, TQ_SIGNAL ( activated ( int ) ), this, TQ_SLOT ( doContextMenuAction ( int ) ) );
 	ContextMenu->show();
 	ContextMenu->setGeometry(pos.x(),pos.y(), ContextMenu->width(),ContextMenu->height());
 }
