@@ -110,9 +110,9 @@ bool ToolInfo::collectToolInfo()
 
 		CollectToolInfoProcess = new TQProcess(this);
 		CollectToolInfoProcess->clearArguments();
-		connect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectToolInfo() ) );
-		connect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectToolInfo() ) );
-		//connect( CollectToolInfoProcess, TQT_SIGNAL( processExited () ), this, TQT_SLOT(processFinished()  ) );
+		connect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectToolInfo() ) );
+		connect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectToolInfo() ) );
+		//connect( CollectToolInfoProcess, TQ_SIGNAL( processExited () ), this, TQ_SLOT(processFinished()  ) );
 		bool run=true;
 
 		//FIXME how it could be better?
@@ -217,15 +217,15 @@ bool ToolInfo::collectToolInfo()
 				}
 
 				//KMessageBox::information(0,TQString("Name: "+Name+", Path: "+PathToExec+", Version: "+Version),"aaa");
-				// 		disconnect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectToolInfo() ) );
-				// 		disconnect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectToolInfo() ) );
+				// 		disconnect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectToolInfo() ) );
+				// 		disconnect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectToolInfo() ) );
 				// 		delete CollectToolInfoProcess;
 				success=true;
 			}
 		}
 
-		disconnect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectToolInfo() ) );
-		disconnect( CollectToolInfoProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectToolInfo() ) );
+		disconnect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectToolInfo() ) );
+		disconnect( CollectToolInfoProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectToolInfo() ) );
 
 		delete CollectToolInfoProcess;
 		CollectToolInfoProcess=0L;
@@ -251,9 +251,9 @@ void ToolInfo::getOpenvpnCapabilities()
 
 		CollectOpenvpnCapabilitiesProcess = new TQProcess(this);
 		CollectOpenvpnCapabilitiesProcess->clearArguments();
-		connect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
-		connect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
-		connect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( processExited () ), this, TQT_SLOT(processFinished()  ) );
+		connect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
+		connect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
+		connect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( processExited () ), this, TQ_SLOT(processFinished()  ) );
 
 		//FIXME how it could be better?
 		CollectOpenvpnCapabilitiesProcess->addArgument(PathToExec);
@@ -278,13 +278,13 @@ void ToolInfo::getOpenvpnCapabilities()
 			}
 
 			//KMessageBox::information(0,TQString("Name: "+Name+", Path: "+PathToExec+", Version: "+Version),"aaa");
-			// 		disconnect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
-			// 		disconnect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
+			// 		disconnect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
+			// 		disconnect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
 			// 		delete CollectOpenvpnCapabilitiesProcess;
 		}
 
-		disconnect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
-		disconnect( CollectOpenvpnCapabilitiesProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
+		disconnect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCollectOpenvpnCapabilies() ) );
+		disconnect( CollectOpenvpnCapabilitiesProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCollectOpenvpnCapabilies() ) );
 
 
 		//std::cout << "Name: " << Name << ", Path: " << PathToExec << ", Version: " << Version << std::endl;
