@@ -144,8 +144,8 @@ bool Utils::tunDevExists()
 bool Utils::createTunDev()
 {
 	createProcess = new TQProcess( this );
-	connect( createProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCreateTunDev() ) );
-	connect( createProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCreateTunDev() ) );
+	connect( createProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCreateTunDev() ) );
+	connect( createProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCreateTunDev() ) );
 
 	// step one: create directory
 	if ( !TQDir ( "/dev/net" ).exists() )
@@ -156,8 +156,8 @@ bool Utils::createTunDev()
 
 
 		if ( !createProcess->start(env) ) {
-			disconnect( createProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCreateTunDev() ) );
-			disconnect( createProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCreateTunDev() ) );
+			disconnect( createProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCreateTunDev() ) );
+			disconnect( createProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCreateTunDev() ) );
 			delete createProcess;
 			createProcess=0L;
 			kdError() << "Unable to create tunnel device file!" << endl;
@@ -181,8 +181,8 @@ bool Utils::createTunDev()
 
 	if ( !createProcess->start(env) )
 	{
-		disconnect( createProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCreateTunDev() ) );
-		disconnect( createProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCreateTunDev() ) );
+		disconnect( createProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCreateTunDev() ) );
+		disconnect( createProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCreateTunDev() ) );
 		delete createProcess;
 		createProcess = 0L;
 		kdError() << "Unable to create tunnel device file!" << endl;
@@ -194,8 +194,8 @@ bool Utils::createTunDev()
 		{
 			sleep ( 1 );
 		}
-		disconnect( createProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutCreateTunDev() ) );
-		disconnect( createProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrCreateTunDev() ) );
+		disconnect( createProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutCreateTunDev() ) );
+		disconnect( createProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrCreateTunDev() ) );
 		delete createProcess;
 		createProcess = 0L;
 		return true;
@@ -212,11 +212,11 @@ bool Utils::loadKernelModule( TQString Name, TQApplication *app )
 		ModprobeProcess->addArgument( "/sbin/modprobe" );
 		ModprobeProcess->addArgument( Name );
 
-		connect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-		connect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+		connect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+		connect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 		if ( !ModprobeProcess->start( env ) ) {
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 			delete ModprobeProcess;
 			ModprobeProcess = 0L;
 			return modprobeSuccess;
@@ -231,8 +231,8 @@ bool Utils::loadKernelModule( TQString Name, TQApplication *app )
 					config->appPointer->processEvents();
 				usleep(250);
 			}
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 			delete ModprobeProcess;
 			ModprobeProcess = 0L;
 			return modprobeSuccess;
@@ -256,11 +256,11 @@ bool Utils::unloadKernelModule( TQString Name, TQApplication *app , bool force)
 
 		ModprobeProcess->addArgument( Name );
 
-		connect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-		connect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+		connect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+		connect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 		if ( !ModprobeProcess->start( env ) ) {
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 			delete ModprobeProcess;
 			ModprobeProcess = 0L;
 			return modprobeSuccess;
@@ -275,8 +275,8 @@ bool Utils::unloadKernelModule( TQString Name, TQApplication *app , bool force)
 					config->appPointer->processEvents();
 				usleep(250);
 			}
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutLoadKernelModule() ) );
-			disconnect( ModprobeProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutLoadKernelModule() ) );
+			disconnect( ModprobeProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrLoadKernelModule() ) );
 			delete ModprobeProcess;
 			ModprobeProcess = 0L;
 			return modprobeSuccess;
@@ -514,13 +514,13 @@ TQStringList Utils::getOpenvpnCiphers()
 	OpenvpnCiphersProcess->addArgument( pathToOpenvpn );
 	OpenvpnCiphersProcess->addArgument( "--show-ciphers" );
 
-	connect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
-	connect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
+	connect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
+	connect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
 
 	if ( !OpenvpnCiphersProcess->start( env ) ) {
 
-		disconnect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
-		disconnect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
+		disconnect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
+		disconnect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
 		delete OpenvpnCiphersProcess;
 		OpenvpnCiphersProcess=0L;
 		kdError() << "Unable to fetch openvpn ciphers!" << endl;
@@ -533,8 +533,8 @@ TQStringList Utils::getOpenvpnCiphers()
 			config->appPointer->processEvents();
 			sleep ( 1 );
 		}
-		disconnect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
-		disconnect( OpenvpnCiphersProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
+		disconnect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnCiphers() ) );
+		disconnect( OpenvpnCiphersProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnCiphers() ) );
 		delete OpenvpnCiphersProcess;
 		OpenvpnCiphersProcess=0L;
 	}
@@ -565,12 +565,12 @@ Utils::IpsecAlgos Utils::getIpsecAlgos()
 	IpsecAlgosProcess->addArgument( "auto" );
 	IpsecAlgosProcess->addArgument( "--status" );
 
-	connect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveIpsecAlgos() ) );
-	connect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveIpsecAlgos() ) );
+	connect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveIpsecAlgos() ) );
+	connect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveIpsecAlgos() ) );
 
 	if ( !IpsecAlgosProcess->start( env ) ) {
-	disconnect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveIpsecAlgos() ) );
-	disconnect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveIpsecAlgos() ) );
+	disconnect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveIpsecAlgos() ) );
+	disconnect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveIpsecAlgos() ) );
 	delete IpsecAlgosProcess;
 	IpsecAlgosProcess=0L;
 		kdError() << "Unable to fetch ipsec algos!" << endl;
@@ -583,8 +583,8 @@ Utils::IpsecAlgos Utils::getIpsecAlgos()
 			config->appPointer->processEvents();
 			sleep ( 1 );
 		}
-		disconnect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveIpsecAlgos() ) );
-		disconnect( IpsecAlgosProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveIpsecAlgos() ) );
+		disconnect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveIpsecAlgos() ) );
+		disconnect( IpsecAlgosProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveIpsecAlgos() ) );
 		delete IpsecAlgosProcess;
 		IpsecAlgosProcess=0L;
 	}
@@ -743,8 +743,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 		TestPppdProcess->setCommunication ( TQProcess::Stdin | TQProcess::Stdout | TQProcess::Stderr | TQProcess::DupStderr );
 		TestPppdProcess->closeStdin ();
 
-		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
-// 		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+// 		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 		
 		if ( !TestPppdProcess->start ( env ) )
 		{
@@ -772,8 +772,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 				config->appendLogEntry ( "pppdHasRequireMppeSupport: false", config->debug );
 
 		}
-		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
-// 		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+// 		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 
 		delete TestPppdProcess;
 		TestPppdProcess=0L;
@@ -790,8 +790,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 		TestPppdProcess->setCommunication ( TQProcess::Stdin | TQProcess::Stdout | TQProcess::Stderr | TQProcess::DupStderr );
 		TestPppdProcess->closeStdin ();
 
-		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
-// 		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+// 		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 		
 		if ( !TestPppdProcess->start ( env ) )
 		{
@@ -826,8 +826,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 				config->appendLogEntry ( "PppdMppeRequired: false", config->debug );
 		}
 
-		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
-// 		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+// 		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 		delete TestPppdProcess;
 		testPppdMppeRequired=false;
 
@@ -858,8 +858,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 		TestPppdProcess->setCommunication ( TQProcess::Stdin | TQProcess::Stdout | TQProcess::Stderr | TQProcess::DupStderr );
 		TestPppdProcess->closeStdin ();
 
-		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
- 		connect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+ 		connect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 
 
 		if ( !TestPppdProcess->start ( env ) )
@@ -887,8 +887,8 @@ Utils::PppdCapabilities Utils::checkPppdCapabilities()
 					config->appendLogEntry ( i18n ( "Test support of replacedefaultroute pppd: %1" ).arg ( i18n ( "failed" ) ) , config->debug );
 			}
 		}
-		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStdout() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
- 		disconnect ( TestPppdProcess, TQT_SIGNAL ( readyReadStderr() ), this, TQT_SLOT ( readPppdtestProcessOutput() ) );
+		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStdout() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
+ 		disconnect ( TestPppdProcess, TQ_SIGNAL ( readyReadStderr() ), this, TQ_SLOT ( readPppdtestProcessOutput() ) );
 		delete TestPppdProcess;
 		TestPppdProcess=0L;
 
@@ -912,12 +912,12 @@ TQStringList Utils::getOpenvpnDigests()
 	OpenvpnDigestProcess->addArgument( pathToOpenvpn );
 	OpenvpnDigestProcess->addArgument( "--show-digests" );
 
-	connect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnDigests() ) );
-	connect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnDigests() ) );
+	connect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnDigests() ) );
+	connect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnDigests() ) );
 
 	if ( !OpenvpnDigestProcess->start( env ) ) {
-		disconnect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnDigests() ) );
-		disconnect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnDigests() ) );
+		disconnect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnDigests() ) );
+		disconnect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnDigests() ) );
 		delete OpenvpnDigestProcess;
 		OpenvpnDigestProcess=0L;
 		kdError() << "Unable to fetch openvpn digests!" << endl;
@@ -938,8 +938,8 @@ TQStringList Utils::getOpenvpnDigests()
 			*it = TQString(*it).section(' ',0,0);
 
 	}
-	disconnect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutRetriveOpenvpnDigests() ) );
-	disconnect( OpenvpnDigestProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrRetriveOpenvpnDigests() ) );
+	disconnect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutRetriveOpenvpnDigests() ) );
+	disconnect( OpenvpnDigestProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrRetriveOpenvpnDigests() ) );
 	delete OpenvpnDigestProcess;
 	OpenvpnDigestProcess=0L;
 	return OpenvpnDigests;
@@ -1027,12 +1027,12 @@ TQString Utils::getNameAndPidOfProgramListen( int port )
 	NameAndPidOfProgramListenProcess->addArgument( config->pathToNetstat );
 	NameAndPidOfProgramListenProcess->addArgument( "-ntupl" );
 
-	connect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
-	connect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
+	connect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
+	connect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
 
 	if ( !NameAndPidOfProgramListenProcess->start( env ) ) {
-		disconnect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
-		disconnect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
+		disconnect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
+		disconnect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
 		delete NameAndPidOfProgramListenProcess;
 		NameAndPidOfProgramListenProcess=0L;
 		kdError() << "netstat fails!" << endl;
@@ -1047,8 +1047,8 @@ TQString Utils::getNameAndPidOfProgramListen( int port )
 		}
 
 
-		disconnect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
-		disconnect( NameAndPidOfProgramListenProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
+		disconnect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetNameAndPidOfProgramListen() ) );
+		disconnect( NameAndPidOfProgramListenProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetNameAndPidOfProgramListen() ) );
 		delete NameAndPidOfProgramListenProcess;
 		NameAndPidOfProgramListenProcess=0L;
 	}
@@ -1069,10 +1069,10 @@ TQString Utils::getEmailAddressOfCert(TQString cert)
 	GetEmailAddressOfCertProcess->addArgument( cert );
 	GetEmailAddressOfCertProcess->addArgument( "-subject");
 
-	connect( GetEmailAddressOfCertProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetEmailAddressOfCert() ) );
+	connect( GetEmailAddressOfCertProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetEmailAddressOfCert() ) );
 
 	if ( !GetEmailAddressOfCertProcess->start( env ) ) {
-		disconnect( GetEmailAddressOfCertProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetEmailAddressOfCert() ) );
+		disconnect( GetEmailAddressOfCertProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetEmailAddressOfCert() ) );
 		delete GetEmailAddressOfCertProcess;
 		GetEmailAddressOfCertProcess=0L;
 		kdError() << "GetEmailAddressOfCertProcess" << endl;
@@ -1085,7 +1085,7 @@ TQString Utils::getEmailAddressOfCert(TQString cert)
 			config->appPointer->processEvents();
 			sleep ( 1 );
 		}
-		disconnect( GetEmailAddressOfCertProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetEmailAddressOfCert() ) );
+		disconnect( GetEmailAddressOfCertProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetEmailAddressOfCert() ) );
 		delete GetEmailAddressOfCertProcess;
 		GetEmailAddressOfCertProcess=0L;
 	}
@@ -1117,11 +1117,11 @@ TQStringList Utils::getSmartcardSlots(TQString ProviderLib)
 	}
 	*GetSmartcardSlotsProcess <<  "-L" ;
 
-	connect( GetSmartcardSlotsProcess, TQT_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQT_SLOT(readOutGetSmartcardSlots()));
+	connect( GetSmartcardSlotsProcess, TQ_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQ_SLOT(readOutGetSmartcardSlots()));
 	
 	if ( !GetSmartcardSlotsProcess->start ( TDEProcess::NotifyOnExit, TDEProcess::All ) )
 	{
-		disconnect( GetSmartcardSlotsProcess, TQT_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQT_SLOT(readOutGetSmartcardSlots()));
+		disconnect( GetSmartcardSlotsProcess, TQ_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQ_SLOT(readOutGetSmartcardSlots()));
 		delete GetSmartcardSlotsProcess;
 		GetSmartcardCertsFromSlotProcess=0L;
 		config->appendLogEntry(i18n("Unable to fetch smartcard slots via pkcs11-tool!"), config->error);
@@ -1137,7 +1137,7 @@ TQStringList Utils::getSmartcardSlots(TQString ProviderLib)
 			usleep ( 500 );
 			config->appPointer->processEvents();
 		}
-		disconnect( GetSmartcardSlotsProcess, TQT_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQT_SLOT(readOutGetSmartcardSlots()));
+		disconnect( GetSmartcardSlotsProcess, TQ_SIGNAL( receivedStdout   (  TDEProcess *, char *, int)), this, TQ_SLOT(readOutGetSmartcardSlots()));
 		delete GetSmartcardSlotsProcess;
 		GetSmartcardCertsFromSlotProcess=0L;
 		 if (config->KvpncDebugLevel > 5)
@@ -1184,10 +1184,10 @@ TQStringList Utils::getSmartcardCertsFromSlot(TQString slot,TQString IdType,TQSt
 	else
 		GetSmartcardCertsFromSlotProcess->addArgument("0");
 
-	connect( GetSmartcardCertsFromSlotProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetSmartcardCertsFromSlot() ) );
+	connect( GetSmartcardCertsFromSlotProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetSmartcardCertsFromSlot() ) );
 	
 	if ( !GetSmartcardCertsFromSlotProcess->start( env ) ) {
-		disconnect( GetSmartcardCertsFromSlotProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetSmartcardCertsFromSlot() ) );
+		disconnect( GetSmartcardCertsFromSlotProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetSmartcardCertsFromSlot() ) );
 		delete GetSmartcardCertsFromSlotProcess;
 		GetSmartcardCertsFromSlotProcess=0L;
 		kdError() << "Unable to fetch smartcard slots via pkcs11-tool!" << endl;
@@ -1201,7 +1201,7 @@ TQStringList Utils::getSmartcardCertsFromSlot(TQString slot,TQString IdType,TQSt
 			usleep ( 500 );
 			config->appPointer->processEvents();
 		}
-		disconnect( GetSmartcardCertsFromSlotProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetSmartcardCertsFromSlot() ) );
+		disconnect( GetSmartcardCertsFromSlotProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetSmartcardCertsFromSlot() ) );
 		delete GetSmartcardCertsFromSlotProcess;
 		GetSmartcardCertsFromSlotProcess=0L;
 	}
@@ -1240,11 +1240,11 @@ TQStringList Utils::getCertsFromCiscoCertStore(TQString type)
 
 	GetCertsFromCiscoCertStoreProcess->addArgument( "list");
 	
-	connect( GetCertsFromCiscoCertStoreProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
+	connect( GetCertsFromCiscoCertStoreProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
 	
 	if ( !GetCertsFromCiscoCertStoreProcess->start( env ) )
 	{
-		disconnect( GetCertsFromCiscoCertStoreProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
+		disconnect( GetCertsFromCiscoCertStoreProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
 		delete GetCertsFromCiscoCertStoreProcess;
 		GetCertsFromCiscoCertStoreProcess=0L;
 		kdError() << "Unable to fetch certificates via cisco_cert_mgr!" << endl;
@@ -1259,7 +1259,7 @@ TQStringList Utils::getCertsFromCiscoCertStore(TQString type)
 			if ( config->appPointer->hasPendingEvents () )
 				config->appPointer->processEvents();
 		}
-		disconnect( GetCertsFromCiscoCertStoreProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
+		disconnect( GetCertsFromCiscoCertStoreProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
 		delete GetCertsFromCiscoCertStoreProcess;
 		GetCertsFromCiscoCertStoreProcess=0L;
 	}
@@ -1280,10 +1280,10 @@ TQStringList Utils::getOpenvpnPkcs11Ids(TQString ProviderLib)
 		OpenvpnPkcs11IdsProcess->addArgument( ProviderLib );
 
 
-	connect( OpenvpnPkcs11IdsProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
+	connect( OpenvpnPkcs11IdsProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
 	
 	if ( !OpenvpnPkcs11IdsProcess->start( env ) ) {
-		disconnect( OpenvpnPkcs11IdsProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
+		disconnect( OpenvpnPkcs11IdsProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
 		delete OpenvpnPkcs11IdsProcess;
 		OpenvpnPkcs11IdsProcess=0L;
 		kdError() << "Unable to fetch pkcs11 ids via openvpn!" << endl;
@@ -1297,7 +1297,7 @@ TQStringList Utils::getOpenvpnPkcs11Ids(TQString ProviderLib)
 			usleep ( 500 );
 			config->appPointer->processEvents();
 		}
-		disconnect( OpenvpnPkcs11IdsProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
+		disconnect( OpenvpnPkcs11IdsProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutGetOpenvpnPkcs11Ids() ) );
 		delete OpenvpnPkcs11IdsProcess;
 		OpenvpnPkcs11IdsProcess=0L;
 	}
@@ -1334,10 +1334,10 @@ bool Utils::getNeedsPassphrase(TQString key)
 	NeedsPassphraseProcess->addArgument("pass:aaa");
 	
 
-	connect( NeedsPassphraseProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutNeedsPassphrase() ) );
+	connect( NeedsPassphraseProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutNeedsPassphrase() ) );
 	
 	if ( !NeedsPassphraseProcess->start( env ) ) {
-		disconnect( NeedsPassphraseProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutNeedsPassphrase() ) );
+		disconnect( NeedsPassphraseProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutNeedsPassphrase() ) );
 		delete NetworkDeviceTestProcess;
 		NeedsPassphraseProcess=0L;
 		kdError() << "Unable to start openssl!" << endl;
@@ -1350,7 +1350,7 @@ bool Utils::getNeedsPassphrase(TQString key)
 			usleep ( 500 );
 			config->appPointer->processEvents();
 		}
-		disconnect( NeedsPassphraseProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readOutNeedsPassphrase() ) );
+		disconnect( NeedsPassphraseProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readOutNeedsPassphrase() ) );
 		delete NetworkDeviceTestProcess;
 		NeedsPassphraseProcess=0L;
 	}
@@ -1365,11 +1365,11 @@ TQString Utils::getHostname()
 	GetHostnameProcess = new TQProcess( this );
 	GetHostnameProcess->addArgument( "hostname" );
 
-	connect( GetHostnameProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetHostname() ) );
-	connect( GetHostnameProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetHostname() ) );
+	connect( GetHostnameProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetHostname() ) );
+	connect( GetHostnameProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetHostname() ) );
 	if ( !GetHostnameProcess->start( env ) ) {
-		disconnect( GetHostnameProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetHostname() ) );
-		disconnect( GetHostnameProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetHostname() ) );
+		disconnect( GetHostnameProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetHostname() ) );
+		disconnect( GetHostnameProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetHostname() ) );
 		delete GetHostnameProcess;
 		GetHostnameProcess=0L;
 		kdError() << "Unable to start getHostname process!" << endl;
@@ -1381,8 +1381,8 @@ TQString Utils::getHostname()
 		{
 			usleep(200);
 		}
-		disconnect( GetHostnameProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdOutGetHostname() ) );
-		disconnect( GetHostnameProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErrGetHostname() ) );
+		disconnect( GetHostnameProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdOutGetHostname() ) );
+		disconnect( GetHostnameProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErrGetHostname() ) );
 		delete GetHostnameProcess;
 		GetHostnameProcess=0L;
 		return Hostname;
